<?php

use Botble\Shortcode\Compilers\Shortcode as ShortcodeCompiler;
use Botble\Shortcode\Facades\Shortcode;
use Botble\Team\Models\Team;
use Botble\Theme\Facades\Theme;

app()->booted(function () {
    if (! is_plugin_active('team')) {
        return;
    }

    Shortcode::register('teams', __('Teams'), __('Teams'), function (ShortcodeCompiler $shortcode): string|null {
        $tabs = Shortcode::fields()->getTabsData(['team_id', 'image'], $shortcode);

        $teamIds = collect($tabs)->pluck('team_id')->filter()->all();

        if (! $teamIds) {
            return null;
        }

        $collectionTeams = Team::query()
            ->whereIn('id', $teamIds)
            ->wherePublished()
            ->with(['slugable'])
            ->get();

        $teams = [];

        foreach ($tabs as $tab) {
            if ($tab['team_id']) {
                $team = $collectionTeams->where('id', $tab['team_id'])->first();
                if ($team) {
                    if ($tab['image']) {
                        $team->photo = $tab['image'];
                    }

                    $teams[] = $team;
                }
            }
        }

        return Theme::partial('shortcodes.teams.index', compact('shortcode', 'teams'));
    });

    Shortcode::setAdminConfig('teams', function (array $attributes): string|null {
        $teams = Team::query()
            ->wherePublished()
            ->pluck('name', 'id')
            ->all();

        return Theme::partial('shortcodes.teams.admin', compact('attributes', 'teams'));
    });

    Shortcode::register('team-skill', __('Team skill'), __('Team skill'), function (ShortcodeCompiler $shortcode): string|null {
        $tabs = Shortcode::fields()->getTabsData(['title', 'index'], $shortcode);

        return Theme::partial('shortcodes.team-skill.index', compact('shortcode', 'tabs'));
    });

    Shortcode::setAdminConfig('team-skill', function (array $attributes): string|null {
        return Theme::partial('shortcodes.team-skill.admin', compact('attributes'));
    });
});
